#
# spec file for package lite-xl-plugin-manager
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#

%define baseprogramname lite-xl
Name:           lite-xl-plugin-manager
Version:        1.0.13+git20231205.1feceea
Release:        1.1
Summary:        A %{baseprogramname} plugin manager
%if 0%{?suse_version} > 1500
%else
Group:          Productivity/Text/Editors
%endif
License:        Apache-2.0 AND BSD-3-Clause AND MIT AND Zlib AND SUSE-GPL-2.0-with-linking-exception
URL:            https://github.com/lite-xl/lite-xl-plugin-manager
Source:         %{name}-%{version}.tar.gz
Patch0:         lpm.c.diff
%if 0%{?suse_version} > 1500 || 0%{?sle_version} >= 150600
BuildRequires:  mbedtls-2-devel
%else
BuildRequires:  mbedtls-devel
%endif
BuildRequires:  meson
BuildRequires:  pkgconfig(libgit2)
BuildRequires:  pkgconfig(libzip)
BuildRequires:  pkgconfig(lua) >= 5.4
BuildRequires:  pkgconfig(zlib)
Requires:       %{baseprogramname}
# This can be managed by 'lite-xl-plugin-manager' (lpm)
#Requires:       lite-xl-widgets

%description
* A standalone binary that provides an easy way of installing, and uninstalling
  plugins from lite-xl, as well as different version of lite-xl.
* Can be used by a package manager plugin that works from inside the editor and
  calls this binary.
* Also contains a plugin_manager.lua plugin to integrate the binary with lite
  in the form of an easy-to-use GUI.
* By default in releases, lpm will automatically consume the manifest.json in
  the latest branch of this repository, which corresponds to the most recent versioned release.
* Conforms to SCPS3.

%prep
#%%autosetup
%setup -q
%patch0

%build
%meson -Dstatic=true 
%meson_build

%install
%ifarch i586
install -D -m 0755 "i586-suse-linux/lpm" "%{buildroot}/%{_bindir}/lpm"
%else
install -D -m 0755 "%{_arch}-suse-linux/lpm" "%{buildroot}/%{_bindir}/lpm"
%endif

%files
%{_bindir}/lpm
%license LICENSE
%doc README.md CHANGELOG.md

%changelog
* Tue Dec  5 2023 scott.bradnick@suse.com
- Update to version 1.0.13+git20231205.1feceea:
  * Fixed CI.
  * Fixed error around orphan plugins.
  * Fixed uninitialization.
  * Reworded things, incorporated Guldo's changes.
  * Added in extra error handling.
  * Added in loading screen for welcome dialog.
  * Split off loading screen functionality.
  * Added welcome plugin.
  * Fixed fetch_if_not_present.
  * Added in better error handling.
  * Added `fetch_if_not_present` to allow things to function without internet.
  * Added in a hook for terminal to display an lpm repl.
  * Pre-sorted dependency graphs so that we get consistnet outputs.
  * Fixed actual output spacing.
  * Added in repostiory URL for plugin to id calculation.
  * Guldo's spelling fixes.
  * Added in a proper repo_path.
  * Added in repo path.
  * Removed documentation for non-existent command.
  * Added in check for executable.
  * Invalidate cache in appropriate places.
  * Allowed for generate_manifest to be used on local repositories; will automatically pile one into the directory.
  * Won't actually have an error so simplified.
  * Loosened verification for certificates.
  * Flagged the json library as special as well, as it's required for the plugin_manager to run.
  * Fixed typo.
  * Ensured we always pass around options so we can track progress one way or another.
  * Added in fallback for any plugin lacking a modversion to describe themselves as the latest modversion.
  * Fixed color install/uninstall; type filter wasn't even present. Whoops.
  * Fixed typo.
  * Added in support for --ephemeral.
  * Allowed for generation for repos that are just init.lua by guessing the id better.
  * Made unstub idempotent and incorporated a number of jgm's fixes.
  * Fix some spelling and display of `DEFAULT_REPO_URL` in cli help
* Tue Oct 10 2023 scott.bradnick@suse.com
- Update to version 1.0.12+git20231010.8f2cd87:
  * Updated CHANGELOG.md.
  * Added in an unstub and VIEW readme function.
  * Added a close for write.
  * Improve `mbedtls2` detection in meson
* Fri Sep 22 2023 scott.bradnick@suse.com
- Adding lpm.c.diff to set LPM_VERSION instead of "unknown"
- Update to version 1.0.11+git20230917.1a54a85:
  * Added in borders to table output.
  * Bugfix.
  * Added in table output format.
  * Updated continous tag.
  * Prioritized remote definitions.
  * Fixed a number of issues relating to generating READMEs, and running arbitrary lua files.
  * Fixed issues with constructing symlink bottles.
  * Reverted is_stub stuff.
  * Made desribe more modern.
* Mon Sep 11 2023 Lubos Kocman <lubos.kocman@suse.com>
- Correction of licenses based on the legaldb report
  * Main package is under MIT, however archive contains bundled
    libraries, mostly licensed under BSD-3-Clause, Apache-2.0 and Zlib.
  * Use SUSE-GPL-2.0-with-linking-exception identifier instead of spdx
    which is not recognized
* Sun Sep 10 2023 scott.bradnick@suse.com
- Update to version 1.0.11+git20230910.4129734:
  * Added the ability to unstub plugins.
  * Constructed bottles in the TMP directory, rather than directly in-place.
  * Updated CHANGELOG.md.
  * Fix installing plugins with version containing `.`
  * Don't create user `init.lua` if no custom config was specified
* Thu Sep  7 2023 Scott Bradnick <scott.bradnick@suse.com>
- Leap 15.6 will be using mbedtls for v3 and mbedtls-2 for v2,
  like Tumbleweed
* Sun Aug 27 2023 scott.bradnick@suse.com
- Update to version 1.0.10+git20230827.2452630:
  * Updated CHANGELOG.md.
  * Added in --config flag.
  * Made us clear the entire bottle if we're reconstructing which is a lot safer.
* Fri Aug 18 2023 scott.bradnick@suse.com
- Update to version 1.0.9+git20230818.02b2665:
  * Updated CHANGELOG.md.
  * Minor documentation updates.
  * Made it so we also chmod unzipped gz files.
  * Added .gz to the spec.
  * Allowed for extracting of .gz files without an associated tar.
* Thu Aug 17 2023 scott.bradnick@suse.com
- Update to version 1.0.8+git20230817.6bcc10e:
  * Made things clearer.
  * Added in futureproofing.
  * Add in preprocessor guard for older libgit2 implementations.
- Fixing up 'suse_version' check(s)
* Thu Aug 17 2023 Scott Bradnick <scott.bradnick@suse.com>
- Group has been deprecated for a while now, but 15.5 and possibly 15.6
  will complain about it missing
  * https://fedoraproject.org/wiki/RPMGroups
* Wed Aug 16 2023 Scott Bradnick <scott.bradnick@suse.com>
- .spec updates
  * Adding 'Group' designation
  * Adding 'suse_version' check for mbedtls[-2] BuildRequires
* Wed Aug 16 2023 Scott Bradnick <scott.bradnick@suse.com>
- Incorporating @suntorytimed's i586 install check
* Thu Aug 10 2023 Scott Bradnick <scott.bradnick@suse.com>
- Removing 'Requires: lite-xl-widgets' as that's a plugin that can be installed
  via lpm (or pulled in by other plugins which require it)
* Thu Aug 10 2023 scott.bradnick@suse.com
- Update to version 1.0.8+git20230810.627caff:
  * Should fix issue 36.
  * Updated CHANGELOG.md.
  * Fixed capitalization.
  * Normalized paths to backslashes.
  * Made it so we autoflush stderr, because windows doesn't do this.
  * Added in quick way to just grab and install orphan plugins.
  * Fixed typo.
  * Made -g flag signal whether or not we move to debug builds for cmake.
  * Made sure size comparaisons only occur with files.
  * Moved USERDIR creation down a bit.
* Thu Aug 10 2023 Scott Bradnick <scott.bradnick@suse.com>
- Initial version from upstream
  * See https://github.com/lite-xl/lite-xl-plugins/issues/144
